( cd usr/lib ; rm -rf libgnome-window-settings.so )
( cd usr/lib ; ln -sf libgnome-window-settings.so.1.0.0 libgnome-window-settings.so )
( cd usr/lib ; rm -rf libgnome-window-settings.so.1 )
( cd usr/lib ; ln -sf libgnome-window-settings.so.1.0.0 libgnome-window-settings.so.1 )
